==> imp-2.2.0-pre4.tar.gz: imp-2.2.0-pre4/lib/js/open_contacts.js <==
<script language="JavaScript">
<!--

function open_contacts_ldap_win () {
    param = "directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_ldap_width ?> + ",height=" + <?php echo $lang->contact_ldap_height ?>;
    contacts_window = window.open("<?php $sess->purl('contactsFrame.php3') ?>", "contacts", param);
    if (!contacts_window.opener) contacts_window.opener = self;
}

function open_contacts_ldap_noaddy_win () {
    param = "directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_ldap_noaddy_width ?> + ",height=" + <?php echo $lang->contact_ldap_noaddy_height ?>;
    contacts_window = window.open("<?php $sess->purl('contactsLdapFrame.php3') ?>", "contacts", param);
    if (!contacts_window.opener) contacts_window.opener = self;
}

function open_contacts_win () {
    param = "directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_width ?> + ",height=" + <?php echo $lang->contact_height ?>;
    contacts_window = window.open("<?php $sess->purl('contacts.php3') ?>", "contacts", param);
    if (!contacts_window.opener) contacts_window.opener = self;
}

function open_add_contact_win (args) {
    var base = "<?php $sess->purl('addcontact.php3') ?>";
    var url = "addcontact.php3";
    if (base != url)
	glue = '&';
    else
	glue = '?';
    if (args != "") url = url + glue + args;
    param = "directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_add_width ?> + ",height=" + 
	<?php echo $lang->contact_add_height ?>;
    add_contact_window = window.open(url, "add_contact", param);
    if (!add_contact_window.opener) add_contact_window.opener=self;
}

//-->
</script>

==> imp_2.2.6.orig.tar.gz: imp-2.2.6.orig/lib/js/open_contacts.js <==
<script language="JavaScript">
<!--

<?php if ($default->use_ldap_search): ?>
function open_contacts_ldap_win () {
    param = "directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_ldap_width ?> + ",height=" + <?php echo $lang->contact_ldap_height ?>;
    contacts_window = window.open("<?php $sess->purl('contactsFrame.php3') ?>", "contacts", param);
    if (!contacts_window.opener) contacts_window.opener = self;
}

function open_contacts_ldap_noaddy_win () {
    param = "directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_ldap_noaddy_width ?> + ",height=" + <?php echo $lang->contact_ldap_noaddy_height ?>;
    contacts_window = window.open("<?php $sess->purl('contactsLdapFrame.php3') ?>", "contacts", param);
    if (!contacts_window.opener) contacts_window.opener = self;
}
<?php endif; ?>

function open_contacts_win () {
    param = "directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_width ?> + ",height=" + <?php echo $lang->contact_height ?>;
    contacts_window = window.open("<?php $sess->purl('contacts.php3') ?>", "contacts", param);
    if (!contacts_window.opener) contacts_window.opener = self;
}

function open_add_contact_win (args) {
    var base = "addcontact.php3";
    var url = "<?php $sess->purl('addcontact.php3') ?>";
    if (base != url)
	glue = '&';
    else
	glue = '?';
    if (args != "") url = url + glue + args;
    param = "directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_add_width ?> + ",height=" + 
	<?php echo $lang->contact_add_height ?>;
    add_contact_window = window.open(url, "add_contact", param);
    if (!add_contact_window.opener) add_contact_window.opener=self;
}

//-->
</script>
